=======================
The ``taurex`` program
=======================

This section of the documentation deals with 
using the main ``taurex`` program is accessed simply
by running in the command line::

    taurex

a help can be accessed by doing::

    taurex --help




------------------------------

.. toctree::
    :maxdepth: 4

    Quickstart <quickstart>
    Input File Format <inputfile>
    Custom Types <custom>
    Global Settings <global>
    Chemistry <chemistry>
    Temperature <temperature>
    Pressure <pressure>
    Planet <planet>
    Star <star>
    Forward Models <models>
    Observation <observation>
    Binning <binning>
    Instrument <instrument>
    Fitting <fitting>
    Derive <derived>
    Mixins <mixins>
    Optimizer <optimizer>
    Plotting <plotting>

